#[non_exhaustive]pub enum ErrorKind {
NotEnoughElements(usize),
TooManyElements(usize),
ListNotAllowed,
SymbolNotAllowed,
StringParsing(&'static str),
UnknownField(Box<str>),
InvalidElement,
}Expand description
The kind of error that occurred during token parsing.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotEnoughElements(usize)
The sublist contains fewer elements than the given minimum.
TooManyElements(usize)
The sublist contains more elements than expected by a specified amount.
ListNotAllowed
No list is allowed in this context.
SymbolNotAllowed
No symbol is allowed in this context.
StringParsing(&'static str)
String parsing failed for the named type.
UnknownField(Box<str>)
The named field does not exist.
InvalidElement
Some specific element is invalid.