Unit

Enum Unit 

pub enum Unit {
    Symbol(Box<str>, Span),
    Parser(Parser),
}
Some unit, which represents an intermediate state.

Variants



Symbol(Box<str>, Span)

The current unit is a single symbol.



Parser(Parser)

The current unit is a parser, which can yield multiple units.

Implementations

Source

impl Unit

pub fn span(&self) -> Span

Returns the source span of this unit.

pub fn symbol(self) -> Result<Box<str>>

Returns the symbol, if applicable, as a result type.

pub fn parser(self) -> Result<Parser>

Returns the parser, if applicable, as a result type.

pub fn substitute(&mut self, variable: &str, value: &str)

Replaces all occurrences of a symbol with another symbol, recursively.