macro_rules! derive_symbol_unparsable {
($t:ty) => { ... };
($t:ty, $($rest:ty),+) => { ... };
}Expand description
Derives Unparsable from symbol for types which implement Display.
macro_rules! derive_symbol_unparsable {
($t:ty) => { ... };
($t:ty, $($rest:ty),+) => { ... };
}Derives Unparsable from symbol for types which implement Display.