pub struct Span {
pub line: usize,
pub column: usize,
pub start: usize,
pub end: usize,
}Expand description
A source range with line, column, and byte offsets.
Fields
line: usizeThe line number of the start position (0-based).
column: usizeThe column number of the start position (0-based).
start: usizeThe byte offset of the start of the span within the source.
end: usizeThe byte offset one past the end of the span within the source.